==> ews-javascript-api-0.1.2.tgz: package/js/PropertyDefinitions/GroupMemberPropertyDefinition.js <==
var __extends = this.__extends || function (d, b) {
    for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p];
    function __() { this.constructor = d; }
    __.prototype = b.prototype;
    d.prototype = new __();
};
var ServiceObjectPropertyDefinition_1 = require("./ServiceObjectPropertyDefinition");
var XmlElementNames_1 = require("../Core/XmlElementNames");
var ExtensionMethods_1 = require("../ExtensionMethods");
var XmlAttributeNames_1 = require("../Core/XmlAttributeNames");
var GroupMemberPropertyDefinition = (function (_super) {
    __extends(GroupMemberPropertyDefinition, _super);
    //private key: string;
    function GroupMemberPropertyDefinition(key) {
        _super.call(this, GroupMemberPropertyDefinition.FieldUri);
        this.Key = key;
    }
    //AddJsonProperties(jsonPropertyDefinition: JsonObject, service: ExchangeService): any { throw new Error("GroupMemberPropertyDefinition.ts - AddJsonProperties : Not implemented."); }
    //GetJsonType(): string { throw new Error("GroupMemberPropertyDefinition.ts - GetJsonType : Not implemented."); }
    GroupMemberPropertyDefinition.prototype.GetPrintableName = function () { return ExtensionMethods_1.StringHelper.Format("{0}:{1}", GroupMemberPropertyDefinition.FieldUri, this.Key); };
    GroupMemberPropertyDefinition.prototype.GetXmlElementName = function () { return XmlElementNames_1.XmlElementNames.IndexedFieldURI; };
    GroupMemberPropertyDefinition.prototype.WriteAttributesToXml = function (writer) {
        _super.prototype.WriteAttributesToXml.call(this, writer);
        writer.WriteAttributeValue("", XmlAttributeNames_1.XmlAttributeNames.FieldIndex, this.Key);
    };
    GroupMemberPropertyDefinition.FieldUri = "distributionlist:Members:Member";
    return GroupMemberPropertyDefinition;
})(ServiceObjectPropertyDefinition_1.ServiceObjectPropertyDefinition);
exports.GroupMemberPropertyDefinition = GroupMemberPropertyDefinition;

==> ews-javascript-api-0.1.11.tgz: package/js/PropertyDefinitions/GroupMemberPropertyDefinition.js <==
var __extends = this.__extends || function (d, b) {
    for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p];
    function __() { this.constructor = d; }
    __.prototype = b.prototype;
    d.prototype = new __();
};
var ServiceObjectPropertyDefinition_1 = require("./ServiceObjectPropertyDefinition");
var XmlElementNames_1 = require("../Core/XmlElementNames");
var ExtensionMethods_1 = require("../ExtensionMethods");
var XmlAttributeNames_1 = require("../Core/XmlAttributeNames");
var GroupMemberPropertyDefinition = (function (_super) {
    __extends(GroupMemberPropertyDefinition, _super);
    //private key: string;
    function GroupMemberPropertyDefinition(key) {
        _super.call(this, GroupMemberPropertyDefinition.FieldUri);
        this.Key = key;
    }
    //AddJsonProperties(jsonPropertyDefinition: JsonObject, service: ExchangeService): any { throw new Error("GroupMemberPropertyDefinition.ts - AddJsonProperties : Not implemented."); }
    //GetJsonType(): string { throw new Error("GroupMemberPropertyDefinition.ts - GetJsonType : Not implemented."); }
    GroupMemberPropertyDefinition.prototype.GetPrintableName = function () { return ExtensionMethods_1.StringHelper.Format("{0}:{1}", GroupMemberPropertyDefinition.FieldUri, this.Key); };
    GroupMemberPropertyDefinition.prototype.GetXmlElementName = function () { return XmlElementNames_1.XmlElementNames.IndexedFieldURI; };
    GroupMemberPropertyDefinition.prototype.WriteAttributesToXml = function (writer) {
        _super.prototype.WriteAttributesToXml.call(this, writer);
        writer.WriteAttributeValue(XmlAttributeNames_1.XmlAttributeNames.FieldIndex, this.Key);
    };
    GroupMemberPropertyDefinition.FieldUri = "distributionlist:Members:Member";
    return GroupMemberPropertyDefinition;
})(ServiceObjectPropertyDefinition_1.ServiceObjectPropertyDefinition);
exports.GroupMemberPropertyDefinition = GroupMemberPropertyDefinition;
